@@ -4,7 +4,7 @@ use strict;
 local $^W = 1;
 
 use vars qw /$VERSION/;
-($VERSION) = q $Revision: 1.6 $ =~ /[\d.]+/g;
+($VERSION) = q $Revision: 2.100 $ =~ /[\d.]+/g;
 
 use Regexp::Common qw /pattern clean no_defaults/;
 
@@ -164,6 +164,14 @@ captures the entire expression
 =head1 HISTORY
 
  $Log: balanced.pm,v $
+ Revision 2.100  2003/01/21 23:19:40  abigail
+ The whole world understands RCS/CVS version numbers, that 1.9 is an
+ older version than 1.10. Except CPAN. Curse the idiot(s) who think
+ that version numbers are floats (in which universe do floats have
+ more than one decimal dot?).
+ Everything is bumped to version 2.100 because CPAN couldn't deal
+ with the fact one file had version 1.10.
+
  Revision 1.6  2002/08/20 15:20:48  abigail
  Documented -begin and -end
 
